@@ -9,7 +9,7 @@ This module provides the following classes:
 """
 from typing import Any, Dict, List
 
-from marshmallow import EXCLUDE, Schema, ValidationError, fields, post_load
+from marshmallow import EXCLUDE, Schema, ValidationError, fields, post_load, pre_load
 
 from simyan.exceptions import APIError
 from simyan.generic_entries import GenericEntrySchema, ImageEntrySchema, IssueEntrySchema
@@ -34,7 +34,7 @@ class VolumeResult:
         issue_count (int): Number of issues in the Volume.
         last_issue (IssueEntry): Last issue of the Volume.
         name (str): Name/Title of the Volume.
-        publisher (GenericEntry): The publisher of the Volume.
+        publisher (GenericEntry, Optional): The publisher of the Volume.
         site_url (str): Url to the ComicVine Website.
         start_year (int, Optional): The year the Volume started.
         summary (str, Optional): Short description of the Volume.
@@ -59,7 +59,7 @@ class VolumeResultSchema(Schema):
     issue_count = fields.Int(data_key="count_of_issues")
     last_issue = fields.Nested(IssueEntrySchema)
     name = fields.Str()
-    publisher = fields.Nested(GenericEntrySchema)
+    publisher = fields.Nested(GenericEntrySchema, allow_none=True)
     site_url = fields.Url(data_key="site_detail_url")
     start_year = fields.Int(allow_none=True)
     summary = fields.Str(data_key="deck", allow_none=True)
@@ -71,6 +71,25 @@ class VolumeResultSchema(Schema):
         dateformat = "%Y-%m-%d %H:%M:%S"
         datetimeformat = "%Y-%m-%d %H:%M:%S"
 
+    @pre_load
+    def process_input(self, data: Dict[str, Any], **kwargs) -> Dict[str, Any]:
+        """
+        Handle non-int values for start_year.
+
+        Args:
+            data: Data from the ComicVine response
+            **kwargs:
+
+        Returns:
+            ComicVine response with the start year either None or Int.
+        """
+        if "start_year" in data and data["start_year"]:
+            try:
+                data["start_year"] = int(data["start_year"])
+            except ValueError:
+                data["start_year"] = None
+        return data
+
     @post_load
     def make_object(self, data: Dict[str, Any], **kwargs) -> VolumeResult:
         """
