@@ -7,19 +7,19 @@ import os
 
 import pytest
 
-from simyan import create_session
+from simyan.session import Session
 from simyan.sqlite_cache import SQLiteCache
 
 
 @pytest.fixture(scope="session")
 def comicvine_api_key():
     """Set the ComicVine API key fixture."""
-    return os.getenv("COMICVINE_API_KEY", "INVALID")
+    return os.getenv("COMICVINE_API_KEY", default="INVALID")
 
 
 @pytest.fixture(scope="session")
-def comicvine(comicvine_api_key):
+def comicvine(comicvine_api_key) -> Session:
     """Set the Simyan session fixture."""
-    return create_session(
+    return Session(
         api_key=comicvine_api_key, cache=SQLiteCache("tests/Simyan-Cache.sqlite", expiry=None)
     )
