@@ -6,6 +6,7 @@ This module contains tests for Volume objects.
 import pytest
 
 from simyan.exceptions import APIError
+from simyan.session import Session as Comicvine
 
 FIRST_ISSUE_ID = 111265
 ID = 18216
@@ -16,7 +17,7 @@ PUBLISHER_ID = 10
 START_YEAR = 2005
 
 
-def test_volume(comicvine):
+def test_volume(comicvine: Comicvine):
     """Test for a known volume."""
     result = comicvine.volume(ID)
     assert result.characters[0].id == 11202
@@ -34,31 +35,31 @@ def test_volume(comicvine):
     assert result.start_year == START_YEAR
 
 
-def test_volume_invalid_start_year(comicvine):
+def test_volume_invalid_start_year(comicvine: Comicvine):
     """Test the VolumeList with an invalid start year."""
     result = comicvine.volume(106032)
     assert result.start_year is None
 
 
-def test_volume_no_start_year(comicvine):
+def test_volume_no_start_year(comicvine: Comicvine):
     """Test the Volume with no start year."""
     result = comicvine.volume(88330)
     assert result.start_year is None
 
 
-def test_volume_no_publisher(comicvine):
+def test_volume_no_publisher(comicvine: Comicvine):
     """Test the Volume with no Publisher."""
     result = comicvine.volume(89312)
     assert result.publisher is None
 
 
-def test_volume_fail(comicvine):
+def test_volume_fail(comicvine: Comicvine):
     """Test for a non-existent volume."""
     with pytest.raises(APIError):
         comicvine.volume(-1)
 
 
-def test_volume_list(comicvine):
+def test_volume_list(comicvine: Comicvine):
     """Test the VolumeList."""
     search_results = comicvine.volume_list({"filter": f"name:{NAME}"})
     result = [x for x in search_results if x.id == ID][0]
@@ -71,28 +72,40 @@ def test_volume_list(comicvine):
     assert result.start_year == START_YEAR
 
 
-def test_volume_list_invalid_start_year(comicvine):
+def test_volume_list_invalid_start_year(comicvine: Comicvine):
     """Test the VolumeList with an invalid start year."""
     search_results = comicvine.volume_list({"filter": "name:Archie"})
     result = [x for x in search_results if x.id == 106032][0]
     assert result.start_year is None
 
 
-def test_volume_list_no_start_year(comicvine):
+def test_volume_list_no_start_year(comicvine: Comicvine):
     """Test the VolumeList with no start year."""
     search_results = comicvine.volume_list({"filter": "name:The Flash"})
     result = [x for x in search_results if x.id == 88330][0]
     assert result.start_year is None
 
 
-def test_volume_list_no_publisher(comicvine):
+def test_volume_list_no_publisher(comicvine: Comicvine):
     """Test the VolumeList with no publisher."""
     search_results = comicvine.volume_list({"filter": "name:Archie"})
     result = [x for x in search_results if x.id == 89312][0]
     assert result.publisher is None
 
 
-def test_volume_list_empty(comicvine):
+def test_volume_list_empty(comicvine: Comicvine):
     """Test VolumeList with no results."""
     results = comicvine.volume_list({"filter": "name:INVALID"})
     assert len(results) == 0
+
+
+def test_volume_no_first_issue(comicvine: Comicvine):
+    """Test Volume with no first_issue."""
+    result = comicvine.volume(_id=92409)
+    assert result.first_issue is None
+
+
+def test_volume_no_last_issue(comicvine: Comicvine):
+    """Test Volume with no last_issue."""
+    result = comicvine.volume(_id=92409)
+    assert result.last_issue is None
